COMPMID-674 - Create Google InceptionV3 example

Change-Id: I389e0d4104b7dde60b7cdd612a83f3328517e44c
Reviewed-on: https://eu-gerrit-1.euhpc.arm.com/115804
Tested-by: Jenkins <bsgcomp@arm.com>
Reviewed-by: Anthony Barbier <anthony.barbier@arm.com>
diff --git a/arm_compute/runtime/SubTensor.h b/arm_compute/runtime/SubTensor.h
index bdb229d..ba2f868 100644
--- a/arm_compute/runtime/SubTensor.h
+++ b/arm_compute/runtime/SubTensor.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017 ARM Limited.
+ * Copyright (c) 2017-2018 ARM Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -39,11 +39,12 @@
 public:
     /** Constructor
      *
      * @param[in] parent       Parent tensor
      * @param[in] tensor_shape Shape of the subtensor
      * @param[in] coords       Coordinates of the first subtensor element inside the parent tensor.
      */
-    SubTensor(ITensor *parent, const TensorShape &tensor_shape, const Coordinates &coords);
+    SubTensor(ITensor *parent, const TensorShape &tensor_shape, const Coordinates &coords, bool extend_parent = false);
     /** Destructor: free the tensor's memory */
     ~SubTensor() = default;
     /** Restrict instances of this class to be copy constructed */
@@ -39,11 +39,12 @@
     /** Constructor
      *
-     * @param[in] parent       Parent tensor
-     * @param[in] tensor_shape Shape of the subtensor
-     * @param[in] coords       Coordinates of the first subtensor element inside the parent tensor.
+     * @param[in] parent        Parent tensor
+     * @param[in] tensor_shape  Shape of the subtensor
+     * @param[in] coords        Coordinates of the first subtensor element inside the parent tensor.
+     * @param[in] extend_parent (Optional) Extend parent with subtensor shape if subtensor indexes out of bounds
      */